/* 
   Project: IMPreferences

   Copyright (C)  2009, 2011 Free Software Foundation

   Author: Germán A. Arias

   Created: 2009-12-29 12:34:53 -0600 by german
   
   Icon Manager Preferences Control 

   This application is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 3 of the License, or (at your option)  any later version.
 
   This application is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/

#include <AppKit/AppKit.h>
#include "IMControl.h"

@protocol GSIconManager
 - (void) setPreferences: (NSArray *)preferences; 
@end

@implementation IMControl

- (void) awakeFromNib
{
  NSString *path = GSDefaultsRootForUser(NSUserName());
  path = [path stringByAppendingString: @"/gsim.plist"];
  NSArray *userPrefs = [NSArray arrayWithContentsOfFile: path];
  
  if ([userPrefs count] == 5)
    {
      orderX = [[[userPrefs objectAtIndex: 0] description] intValue];
      orderY = [[[userPrefs objectAtIndex: 1] description] intValue];
      
      if ( (orderX == 1) && (orderY == 0) )
        {
	  [howAdded setState: NSOnState atRow: 0 column: 0];
        }
      
      if ( (orderX == -1) && (orderY == 0) )
        {
	  [howAdded setState: NSOnState atRow: 0 column: 1];
        }  
      
      if ( (orderX == 0) && (orderY == 1) )
        {
	  [howAdded setState: NSOnState atRow: 1 column: 0];
        }
      
      if ( (orderX == 0) && (orderY == -1) )
        {
	  [howAdded setState: NSOnState atRow: 1 column: 1];
        }
      
      [xOrigin setStringValue: [[userPrefs objectAtIndex: 2] description]];    
      [yOrigin setStringValue: [[userPrefs objectAtIndex: 3] description]];
      [size setFloatValue: [[[userPrefs objectAtIndex: 4] description] intValue]];
      [sizeLabel setStringValue: [[userPrefs objectAtIndex: 4] description]]; 
    }
  else  
    {
      [howAdded setState: NSOnState atRow: 1 column: 0];
      
      orderX = 0;
      orderY = 1;
      [xOrigin setIntValue: 0];    
      [yOrigin setIntValue: 50];
      [size setFloatValue: 32];
      [sizeLabel setIntValue: 32]; 
    }
}


- (void) howAreAdded: (id)sender
{
  switch ([[sender selectedCell] tag])
    {
    case 0:
      {
	orderX = 1;
	orderY = 0;
      }
      break;
    case 1:
      {
	orderX = -1;
	orderY = 0;                   
      }
      break;
    case 2:
      {
	orderX = 0;
	orderY = 1;                   
      }
      break;
    case 3:
      {
	orderX = 0;
	orderY = -1;                   
      }
      break;            
    }
}


- (void) iconsSize: (id)sender
{
  [sizeLabel setFloatValue: [sender floatValue]];
}


- (void) savePreferences: (id)sender
{
  id <GSIconManager>gsim = nil;
  NSMutableArray *preferences = [NSMutableArray array];
  
  gsim = (id <GSIconManager>)[NSConnection rootProxyForConnectionWithRegisteredName: @"GSIconManager"
    host: @""];
   
  if (gsim == nil)
    {
      NSLog (@"Error: could not connect to server GSIconManager");
    }

  [preferences addObject: [NSNumber numberWithInt: orderX]];
  [preferences addObject: [NSNumber numberWithInt: orderY]];
  [preferences addObject: [NSNumber numberWithUnsignedInt: [xOrigin intValue]]];
  [preferences addObject: [NSNumber numberWithUnsignedInt: [yOrigin intValue]]];
  [preferences addObject: [NSNumber numberWithUnsignedInt: [sizeLabel intValue]]];
  
  NSString *path = GSDefaultsRootForUser(NSUserName());
  path = [path stringByAppendingString: @"/gsim.plist"];  
  [[preferences description] writeToFile: path atomically: YES];
  
  [gsim setPreferences: preferences];
}

@end
